% Least square approximation for pipeline pressuredrop
% Created by Sindre Sangnes and Jakob Hansen-Tangen

%Take in all relevant data
filename = 'Pipeline1_production_subsea1.xlsx';
data = xlsread(filename,'Data_sortedWC_uten0flow');

%indata - oilflows, gasflows and waterflows
oilflows = data(:,1);
gasflows = data(:,2);
waterflows = data(:,3);

%outdata - pressure drop resulting from qoil, qgas and qwater
pressuredrop = data(:,4);

%plot the given pressuredrop
figure(1);clf
tri = delaunay(oilflows,gasflows);

h = trisurf(tri, oilflows, gasflows, pressuredrop); hold on
axis vis3d

xlabel('Oil flow [m^3/d]');
ylabel('Gas flow [m^3/d]');
zlabel('Pressure drop [kgf/cm]');

camlight right
shading interp
lighting phong

%Take in relevant data for the curvefit
dataIN = [oilflows, gasflows, waterflows];
dataOUT = pressuredrop;

b0 = [0 0 0 0 0 0 0 0 0 0 0 0 0];

options = optimset('MaxFunEvals',1e10);

% Run the least square for the data and approximation function
[b, resnorm, residual] = lsqcurvefit(@manifold1Func_line1,b0,dataIN,dataOUT,-1000000,1000000,options) %, residual

approximated_pressuredrop = manifold1Func_line1(b, dataIN);

% Plot the data for all points (this will not give a good representation,
% since data for all watercuts are included)
h2 = trisurf(tri, oilflows, gasflows, approximated_pressuredrop);
lighting phong
