%sketch comparing simulated data and approximated data for wc=0

%Take in the relevant data, simulated and approximated by the curvefit
filename = 'approx_sketch_wc0.xlsx';
data = xlsread(filename,'wc0_uten0flow 13b');

oilflows = data(:,1);
gasflows = data(:,2);
waterflows = data(:,3);
pressuredrop = data(:,4);
approximated_pressuredrop = data(:,6);

figure(1);clf
tri = delaunay(oilflows,gasflows);

h = trisurf(tri, oilflows, gasflows, pressuredrop); hold on
axis vis3d

shading interp
lighting phong
alpha(.6)

%Plot approximated pressuredrop
h2 = trisurf(tri, oilflows, gasflows, approximated_pressuredrop);
set(h2, 'FaceColor', 'c')
lighting phong
camlight right

xlabel('Oil flow [m^3/d]');
ylabel('Gas flow [m^3/d]');
zlabel('Pressure drop [kgf/cm]');

%Find the residuals for the plot
residual = pressuredrop - approximated_pressuredrop; %residuals are the difference bew orig and approx data

%Create a new plot for the residuals
figure(2);clf

xyplane = oilflows.*0 + gasflows.*0;
zeroplan = trisurf(tri, oilflows, gasflows, xyplane); hold on

set(zeroplan,'FaceColor','c', 'Edgecolor', 'none')
lighting phong
alpha(.8)

rplot = trisurf(tri, oilflows, gasflows, residual);
set(rplot, 'FaceColor', 'interp','FaceLighting','phong'); % 'Edgecolor','none'
lighting phong
camlight right

xlabel('Oil flow [m^3/d]');
ylabel('Gas flow [m^3/d]');
zlabel('Residuals (diff Pressure drop [kgf/cm])');
