% Least square curve fit with corresponding plots for one of the wells.
% Created by Sindre Sangnes and Jakob Hansen-Tangen

%Read data
filename = 'Data_well_129.xlsx';
data = xlsread(filename);

%indata - wellhead pressure and injected lift gas
wh_pressures = data(:,1);
liftgas_in = data(:,2);

%outdata - oil flow resulting from wh pressure and lift gas
oilflows = data(:,3);

%Plot original data
figure(1);clf
tri = delaunay(wh_pressures,liftgas_in);
plot(wh_pressures,liftgas_in,'.');

h = trisurf(tri, wh_pressures, liftgas_in, oilflows); hold on
axis vis3d

%set(h, 'FaceColor', 'red', 'Edgecolor','none')
shading interp
lighting phong
alpha(.8)
hold all

% Take in relevant datafor the curve fit
dataIN = [wh_pressures, liftgas_in];
dataOUT = oilflows;

a0 = [10 10 10 10 10 10];

%Running the least square fit for the relevant well function
[a, resnorm] = lsqcurvefit(@wellFunc_129,a0,dataIN,dataOUT)

approximated_oilflows = wellFunc_129(a, dataIN);

%Plot approximated oil flows
h2 = trisurf(tri, wh_pressures, liftgas_in, approximated_oilflows);
set(h2, 'FaceColor', 'c')
lighting phong

camlight right

xlabel('Wellhead pressure [kgf/cm^2]');
ylabel('Lift Gas Injected[m^3/d]');
zlabel('Oil flow [m^3/d]');

%Make a new plot for the residuals
residual = oilflows - approximated_oilflows;
figure(2);clf

xyplane = wh_pressures.*0 + liftgas_in.*0;
zeroplane = trisurf(tri, wh_pressures, liftgas_in, xyplane); hold on
set(zeroplane,'FaceColor','c', 'Edgecolor', 'none')
lighting phong
alpha(.8)

residualplot = trisurf(tri, wh_pressures, liftgas_in, residual);
set(residualplot, 'FaceColor', 'interp','FaceLighting','phong'); % 'Edgecolor','none'
lighting phong
camlight right

xlabel('Wellhead pressure [kgf/cm^2]');
ylabel('Lift Gas Injected[m^3/d]');
zlabel('Residual Oil flow [m^3/d]');